@@ -9,6 +9,7 @@ class ScheduleType(StrEnum):
     THERM = "therm"
     COOLING = "cooling"
     ELECTRICITY = "electricity"
+    ELECTRICITY_PRODUCTION = "electricity_production"
     EVENT = "event"
     AUTO = "auto"
 
@@ -20,7 +21,7 @@ class TemperatureControlMode(StrEnum):
     COOLING = "cooling"
 
 
-SCHEDULE_TYPE_MAPPING = {
+SCHEDULE_TYPE_MAPPING: dict[TemperatureControlMode, ScheduleType] = {
     TemperatureControlMode.HEATING: ScheduleType.THERM,
     TemperatureControlMode.COOLING: ScheduleType.COOLING,
 }
