@@ -3,7 +3,7 @@
 from __future__ import annotations
 
 import logging
-from typing import TYPE_CHECKING, cast
+from typing import TYPE_CHECKING, Any, cast
 
 from pyatmo.exceptions import NoDeviceError
 
@@ -44,7 +44,7 @@ def extract_raw_data(resp: RawData, tag: str) -> RawData:
         raise NoDeviceError(msg)
 
     if tag == "homes":
-        homes = fix_id(resp["body"].get(tag))
+        homes: list[dict[str, Any] | str] = fix_id(resp["body"].get(tag))
         if not homes:
             LOG.debug("Server response (tag: %s): %s", tag, resp)
             msg = "No homes found"
