@@ -13,7 +13,7 @@ if TYPE_CHECKING:
 
     from .home import Home
 
-LOG = logging.getLogger(__name__)
+LOG: logging.Logger = logging.getLogger(__name__)
 
 
 @dataclass
